@@ -1,13 +1,7 @@
 # -*- coding: utf-8 -*-
-import base64
-import hashlib
-import hmac
 
-import time
-from datetime import datetime
 from pagador.seguranca.autenticador import TipoAutenticacao
 from pagador.seguranca.instalacao import Parametros
-from pagador_koin import settings
 from pagador.seguranca import autenticador
 
 
